# Release history

### 0.0.6

* Set ElasticSearch version which currently supports AWS ElasticSearch implementation.

### 0.0.5

* Ensure consistent asset builds.
* Add ability to install boto3 dependency.

### 0.0.4

* Update Docker bundling commands. Use bash to move files between directories instead of installing with `-t` flag. Related
  issue: https://github.com/pypa/pip/issues/103

### 0.0.1

* Initial build.
* Elasticsearch-python 7.9.1.
* Docker image for asset building: python:3.9.